@@ -7,7 +7,7 @@ use Mite::Miteception -all;
 extends 'Mite::App::Command' => { -version => '0.009000' };
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.010001';
+our $VERSION   = '0.010002';
 
 sub abstract {
     return "Make your code ready to run.";
@@ -30,7 +30,7 @@ sub execute {
 
     if ( $self->config->data->{dogfood} ) {
         $project->_module_fakeout_namespace(
-            sprintf 'A%02d::B%02d', int(rand(100)), int(rand(100))
+            $ENV{FAKEOUT_NAMESPACE} = sprintf 'A%02d::B%02d', int(rand 100), int(rand 100)
         );
     }
 
