@@ -5,7 +5,7 @@ use warnings;
 package Mite::Miteception;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.010001';
+our $VERSION   = '0.010002';
 
 use Import::Into;
 use Mite::Shim ();
@@ -49,13 +49,6 @@ sub load_mite_file {
 		 local @INC = ('.', @INC);
 		 require $mite_file;
 	}
-
-	'Mite::Shim'->_inject_mite_functions(
-		$caller,
-		$file,
-		( $arg{'-role'} ? 'role' : 'class' ),
-		\%arg,
-	);
 }
 
 1;
