@@ -6,7 +6,7 @@ package Mite::Package;
 use Mite::Miteception -all;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.010001';
+our $VERSION   = '0.010002';
 
 has name =>
   is            => ro,
@@ -33,6 +33,13 @@ has imported_functions =>
   isa           => Map[ MethodName, Str ],
   builder       => sub { {} };
 
+has imported_keywords =>
+  is            => ro,
+  isa           => Map[ MethodName, Str ],
+  builder       => sub { {} };
+
+sub kind { 'package' }
+
 sub BUILD {
     my $self = shift;
 
@@ -52,6 +59,42 @@ sub project {
     return $self->source->project;
 }
 
+sub inject_mite_functions {
+    my ( $self, $file, $arg ) = ( shift, @_ );
+
+    my $requested = sub { $arg->{$_[0]} ? 1 : $arg->{'!'.$_[0]} ? 0 : $arg->{'-all'} ? 1 : $_[1]; };
+    my $shim      = $self->shim_name;
+    my $package   = $self->name;
+    my $ctxt      = $shim->can( '_definition_context' );
+
+    no strict 'refs';
+    ${ $package .'::USES_MITE' } = ref( $self );
+    ${ $package .'::MITE_SHIM' } = $shim;
+
+    my $want_bool = $requested->( '-bool', 0 );
+    my $want_is   = $requested->( '-is',   0 );
+    for my $f ( qw/ true false / ) {
+        next unless $requested->( $f, $want_bool );
+        *{"$package\::$f"} = \&{"$shim\::$f"};
+        $self->imported_functions->{$f} = "$shim\::$f";
+    }
+    for my $f ( qw/ ro rw rwp lazy bare / ) {
+        next unless $requested->( $f, $want_is );
+        *{"$package\::$f"} = \&{"$shim\::$f"};
+        $self->imported_functions->{$f} = "$shim\::$f";
+    }
+    for my $f ( qw/ carp croak confess guard STRICT / ) {
+        next unless $requested->( $f, false );
+        *{"$package\::$f"} = \&{"$shim\::$f"};
+        $self->imported_functions->{$f} = "$shim\::$f";
+    }
+    if ( $requested->( blessed => false ) ) {
+        require Scalar::Util;
+        *{"$package\::blessed"} = \&Scalar::Util::blessed;
+        $self->imported_functions->{blessed} = "Scalar::Util::blessed";
+    }
+}
+
 sub autolax {
     my $self = shift;
 
@@ -99,6 +142,7 @@ sub compilation_stages {
         _compile_package
         _compile_pragmas
         _compile_uses_mite
+        _compile_imported_keywords
         _compile_imported_functions
         _compile_meta_method
     );
@@ -131,11 +175,35 @@ sub _compile_uses_mite {
     join "\n", @code;
 }
 
+sub _compile_imported_keywords {
+    my $self = shift;
+
+    my %func = %{ $self->imported_keywords or {} } or return;
+    my @keywords = sort keys %func;
+    my $keyword_slots = join q{, }, map "*$_", @keywords;
+    my $coderefs = join "\n", map "            $func{$_},", @keywords;
+
+    return sprintf <<'CODE', B::perlstring( $self->shim_name ), B::perlstring( $self->name ), $keyword_slots, $self->shim_name, $coderefs;
+# Mite keywords
+BEGIN {
+    my ( $SHIM, $CALLER ) = ( %s, %s );
+    ( %s ) = do {
+        package %s;
+        no warnings 'redefine';
+        (
+%s
+        );
+    };
+};
+CODE
+}
+
 sub _compile_imported_functions {
     my $self = shift;
     my %func = %{ $self->imported_functions } or return;
 
     return join "\n",
+        '# Mite imports',
         'BEGIN {',
         ( $func{blessed} ? '    require Scalar::Util;' : () ),
         map(
