@@ -7,8 +7,34 @@
 
     our $USES_MITE    = "Mite::Class";
     our $MITE_SHIM    = "Mite::Shim";
-    our $MITE_VERSION = "0.010001";
+    our $MITE_VERSION = "0.010002";
 
+    # Mite keywords
+    BEGIN {
+        my ( $SHIM, $CALLER ) = ( "Mite::Shim", "Mite::Project" );
+        (
+            *after, *around, *before,        *extends, *field,
+            *has,   *param,  *signature_for, *with
+          )
+          = do {
+
+            package Mite::Shim;
+            no warnings 'redefine';
+            (
+                sub { $SHIM->HANDLE_after( $CALLER, "class", @_ ) },
+                sub { $SHIM->HANDLE_around( $CALLER, "class", @_ ) },
+                sub { $SHIM->HANDLE_before( $CALLER, "class", @_ ) },
+                sub { },
+                sub { $SHIM->HANDLE_has( $CALLER, field => @_ ) },
+                sub { $SHIM->HANDLE_has( $CALLER, has   => @_ ) },
+                sub { $SHIM->HANDLE_has( $CALLER, param => @_ ) },
+                sub { $SHIM->HANDLE_signature_for( $CALLER, "class", @_ ) },
+                sub { $SHIM->HANDLE_with( $CALLER, @_ ) },
+            );
+          };
+    }
+
+    # Mite imports
     BEGIN {
         require Scalar::Util;
         *STRICT  = \&Mite::Shim::STRICT;
@@ -415,22 +441,23 @@
         $out{"file"} = $in{"file"} if exists( $in{"file"} );
         delete( $in{"file"} );
 
-        # Parameter kind (type: Str)
-        $dtmp = exists( $in{"kind"} ) ? $in{"kind"} : "class";
-        do {
+        # Parameter kind (type: Optional[Str])
+        if ( exists( $in{"kind"} ) ) {
+            do {
 
-            package Mite::Shim;
-            defined($dtmp) and do {
-                ref( \$dtmp ) eq 'SCALAR'
-                  or ref( \( my $val = $dtmp ) ) eq 'SCALAR';
-            }
-          }
-          or croak(
+                package Mite::Shim;
+                defined( $in{"kind"} ) and do {
+                    ref( \$in{"kind"} ) eq 'SCALAR'
+                      or ref( \( my $val = $in{"kind"} ) ) eq 'SCALAR';
+                }
+              }
+              or croak(
 "Type check failed in signature for inject_mite_functions: %s should be %s",
-            "\$_{\"kind\"}", "Str"
-          );
-        $out{"kind"} = $dtmp;
-        delete( $in{"kind"} );
+                "\$_{\"kind\"}", "Optional[Str]"
+              );
+            $out{"kind"} = $in{"kind"};
+            delete( $in{"kind"} );
+        }
 
         # Parameter arg (type: HashRef)
         $dtmp = exists( $in{"arg"} ) ? $in{"arg"} : {};
