@@ -16,11 +16,13 @@ with qw(
 );
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.010001';
+our $VERSION   = '0.010002';
 
 use Path::Tiny;
 use B ();
 
+sub kind { 'role' }
+
 sub methods_to_export {
     my ( $self, $role_args ) = @_;
 
@@ -106,7 +108,8 @@ sub __FINALIZE_APPLICATION__ {
     my $shim = %s;
     for my $modifier_rule ( @METHOD_MODIFIERS ) {
         my ( $modification, $names, $coderef ) = @$modifier_rule;
-        $shim->$modification( $target, $names, $coderef );
+        my $handler = "HANDLE_$modification";
+        $shim->$handler( $target, "class", $names, $coderef );
     }
 
     return;
