@@ -6,7 +6,7 @@ package Mite::Trait::HasMethods;
 use Mite::Miteception -role, -all;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.010001';
+our $VERSION   = '0.010002';
 
 requires qw( _function_for_croak );
 
@@ -75,6 +75,57 @@ sub native_methods {
     return \%methods;
 }
 
+before inject_mite_functions => sub {
+    my ( $self, $file, $arg ) = ( shift, @_ );
+
+    my $requested = sub { $arg->{$_[0]} ? 1 : $arg->{'!'.$_[0]} ? 0 : $arg->{'-all'} ? 1 : $_[1]; };
+    my $shim      = $self->shim_name;
+    my $package   = $self->name;
+    my $kind      = $self->kind;
+    my $parse_mm_args = $shim->can( '_parse_mm_args' ) || \&Mite::Shim::_parse_mm_args;
+
+    no strict 'refs';
+
+    if ( $requested->( 'signature_for', true ) ) {
+
+        *{ $package .'::signature_for' } = sub {
+            my $name = shift;
+            if ( $name =~ /^\+/ ) {
+                $name =~ s/^\+//;
+                $self->extend_method_signature( $name, @_ );
+            }
+            else {
+                $self->add_method_signature( $name, @_ );
+            }
+            return;
+        };
+
+        $self->imported_keywords->{signature_for} =
+            sprintf 'sub { $SHIM->HANDLE_signature_for( $CALLER, %s, @_ ) }',
+            B::perlstring( $kind );
+    }
+
+    for my $modifier ( qw( before after around ) ) {
+
+        $requested->( $modifier, true ) or next;
+
+        *{ $package .'::'. $modifier } = sub {
+            my ( $names, $coderef ) = &$parse_mm_args;
+            CodeRef->check( $coderef )
+                or croak "Expected a coderef method modifier";
+            ArrayRef->of(Str)->check( $names ) && @$names
+                or croak "Expected a list of method names to modify";
+            $self->add_required_methods( @$names ) if $kind eq 'role';
+            return;
+        };
+
+        $self->imported_keywords->{$modifier} =
+            sprintf 'sub { $SHIM->HANDLE_%s( $CALLER, %s, @_ ) }',
+            $modifier, B::perlstring( $kind );
+
+    }
+};
+
 around compilation_stages => sub {
     my ( $next, $self ) = ( shift, shift );
     my @stages = $self->$next( @_ );
