@@ -6,7 +6,7 @@ package Mite::Trait::HasRequiredMethods;
 use Mite::Miteception -role, -all;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.010001';
+our $VERSION   = '0.010002';
 
 has required_methods =>
   is            => ro,
@@ -21,6 +21,26 @@ sub add_required_methods {
     return;
 }
 
+before inject_mite_functions => sub {
+    my ( $self, $file, $arg ) = ( shift, @_ );
+
+    my $requested = sub { $arg->{$_[0]} ? 1 : $arg->{'!'.$_[0]} ? 0 : $arg->{'-all'} ? 1 : $_[1]; };
+    my $shim      = $self->shim_name;
+    my $package   = $self->name;
+
+    no strict 'refs';
+
+    if ( $requested->( 'requires', 1 ) ) {
+
+        *{ $package .'::requires' } = sub {
+            $self->add_required_methods( @_ );
+            return;
+        };
+
+        $self->imported_keywords->{requires} = 'sub {}';
+    }
+};
+
 around _compile_mop_required_methods => sub {
     my ( $next, $self ) = ( shift, shift );
 
