@@ -6,7 +6,7 @@ package Mite::Trait::HasSuperclasses;
 use Mite::Miteception -role, -all;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.010001';
+our $VERSION   = '0.010002';
 
 # Super classes as class names
 has extends =>
@@ -124,10 +124,34 @@ sub _get_parent {
     return;
 }
 
+before inject_mite_functions => sub {
+    my ( $self, $file, $arg ) = ( shift, @_ );
+
+    my $requested = sub { $arg->{$_[0]} ? 1 : $arg->{'!'.$_[0]} ? 0 : $arg->{'-all'} ? 1 : $_[1]; };
+    my $shim      = $self->shim_name;
+    my $package   = $self->name;
+    my $fake_ns   = $self->project->can('_module_fakeout_namespace') && $self->project->_module_fakeout_namespace;
+
+    no strict 'refs';
+
+    if ( $requested->( 'extends', 1 ) ) {
+
+        *{ $package .'::extends' } = sub {
+            return $self->handle_extends_keyword(
+                defined( $fake_ns )
+                    ? map Str->check($_) ? "$fake_ns\::$_" : $_, @_
+                    : @_
+            );
+        };
+
+        $self->imported_keywords->{'extends'} = 'sub {}';
+    }
+};
+
 around compilation_stages => sub {
     my ( $next, $self ) = ( shift, shift );
     my @stages = $self->$next( @_ );
-    push @stages, '_compile_extends';
+    push @stages, qw( _compile_extends );
     return @stages;
 };
 
